HighlightError

Enum HighlightError 

#[non_exhaustive]
pub enum HighlightError { GrammarLoad { language: Language, message: String, }, Query { language: Language, row: usize, column: usize, offset: usize, kind: HighlightQueryErrorKind, message: String, }, Parse { language: Language, }, InvalidEdit { start_byte: usize, old_end_byte: usize, new_end_byte: usize, old_len: usize, new_len: usize, }, }
A typed error produced while preparing runtime syntax highlighting.

These errors are recoverable for renderers: callers can surface the error and render the original source as plaintext.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


GrammarLoad

The tree-sitter parser rejected the selected grammar.

Fields

language: Language

The language whose grammar failed to load.

message: String

The parser’s diagnostic message.



Query

The tree-sitter highlights query failed to compile.

Fields

language: Language

The language whose query failed.

row: usize

Zero-based query row where the error was reported.

column: usize

Zero-based query column where the error was reported.

offset: usize

Byte offset where the error was reported.

kind: HighlightQueryErrorKind

The query error kind.

message: String

The query compiler’s diagnostic message.



Parse

Tree-sitter failed to parse the source.

Fields

language: Language

The language being parsed.



InvalidEdit

Buffer::edit received offsets that are out of bounds or not on UTF-8 character boundaries.

The buffer’s state is unchanged when this error is returned.

Fields

start_byte: usize

First byte the caller said changed.

old_end_byte: usize

One past the last byte of the replaced region in the previous source.

new_end_byte: usize

One past the last byte of the inserted region in the new source.

old_len: usize

Length of the previous source, for context.

new_len: usize

Length of the new source, for context.