pub struct HighlightSegment<'a> { /* private fields */ }Expand description
A borrowed render segment with an optional highlight tag.
use dioxus_code::advanced::HighlightSegment;
let segment = HighlightSegment::new("fn", Some("k"));
assert_eq!(segment.text(), "fn");Implementations
Sourceimpl<'a> HighlightSegment<'a>
impl<'a> HighlightSegment<'a>
Sourcepub const fn new(text: &'a str, tag: Option<&'static str>) -> Self
pub const fn new(text: &'a str, tag: Option<&'static str>) -> Self
Create a highlighted segment.
use dioxus_code::advanced::HighlightSegment;
let _segment = HighlightSegment::new("fn", Some("k"));Trait Implementations
Sourceimpl<'a> Clone for HighlightSegment<'a>
impl<'a> Clone for HighlightSegment<'a>
Sourcefn clone(&self) -> HighlightSegment<'a>
fn clone(&self) -> HighlightSegment<'a>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for HighlightSegment<'a>
impl<'a> Debug for HighlightSegment<'a>
Sourceimpl<'a> PartialEq for HighlightSegment<'a>
impl<'a> PartialEq for HighlightSegment<'a>
Sourcefn eq(&self, other: &HighlightSegment<'a>) -> bool
fn eq(&self, other: &HighlightSegment<'a>) -> bool
Tests for
self and other values to be equal, and is used by ==.impl<'a> Copy for HighlightSegment<'a>
impl<'a> Eq for HighlightSegment<'a>
impl<'a> StructuralPartialEq for HighlightSegment<'a>