pub struct HighlightSpan { /* private fields */ }Expand description
A highlight span attached to a byte range of source text.
use dioxus_code::advanced::HighlightSpan;
let span = HighlightSpan::new(0..2, "k");
assert_eq!(span.tag(), "k");Implementations
Sourceimpl HighlightSpan
impl HighlightSpan
Sourcepub const fn new(range: Range<u32>, tag: &'static str) -> Self
pub const fn new(range: Range<u32>, tag: &'static str) -> Self
Create a highlight span.
use dioxus_code::advanced::HighlightSpan;
let span = HighlightSpan::new(0..2, "k");
assert_eq!(span.range(), 0..2);Sourcepub const fn from_offsets(start: u32, end: u32, tag: &'static str) -> Self
pub const fn from_offsets(start: u32, end: u32, tag: &'static str) -> Self
Create a highlight span from explicit byte offsets.
use dioxus_code::advanced::HighlightSpan;
let span = HighlightSpan::from_offsets(0, 2, "k");
assert_eq!(span.start(), 0);Sourcepub const fn start(self) -> u32
pub const fn start(self) -> u32
Byte offset, inclusive, of the span’s start in the source.
use dioxus_code::advanced::HighlightSpan;
assert_eq!(HighlightSpan::new(3..5, "k").start(), 3);Sourcepub const fn end(self) -> u32
pub const fn end(self) -> u32
Byte offset, exclusive, of the span’s end in the source.
use dioxus_code::advanced::HighlightSpan;
assert_eq!(HighlightSpan::new(3..5, "k").end(), 5);Trait Implementations
Sourceimpl Clone for HighlightSpan
impl Clone for HighlightSpan
Sourcefn clone(&self) -> HighlightSpan
fn clone(&self) -> HighlightSpan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HighlightSpan
impl Debug for HighlightSpan
Sourceimpl PartialEq for HighlightSpan
impl PartialEq for HighlightSpan
Sourcefn eq(&self, other: &HighlightSpan) -> bool
fn eq(&self, other: &HighlightSpan) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for HighlightSpan
impl Eq for HighlightSpan
impl StructuralPartialEq for HighlightSpan