pub struct CodeOptions { /* private fields */ }Expand description
Compile-time options for the code! macro.
The code! macro reads this builder syntactically; pass
CodeOptions::builder with CodeOptions::with_language to override the
language that would otherwise be inferred from the file extension.
use dioxus_code::{CodeOptions, Language, code};
let _source = code!(
"/snippets/demo.rs",
CodeOptions::builder().with_language(Language::Rust)
);Implementations
Sourceimpl CodeOptions
impl CodeOptions
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Create default code options.
use dioxus_code::CodeOptions;
let _opts = CodeOptions::new();Sourcepub const fn builder() -> Self
pub const fn builder() -> Self
Create default code options.
Alias for Self::new, matching builder-style asset APIs.
use dioxus_code::{CodeOptions, Language};
let _opts = CodeOptions::builder().with_language(Language::Rust);Trait Implementations
Sourceimpl Clone for CodeOptions
impl Clone for CodeOptions
Sourcefn clone(&self) -> CodeOptions
fn clone(&self) -> CodeOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CodeOptions
impl Debug for CodeOptions
Sourceimpl Default for CodeOptions
impl Default for CodeOptions
Sourcefn default() -> CodeOptions
fn default() -> CodeOptions
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for CodeOptions
impl PartialEq for CodeOptions
Sourcefn eq(&self, other: &CodeOptions) -> bool
fn eq(&self, other: &CodeOptions) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for CodeOptions
impl Eq for CodeOptions
impl StructuralPartialEq for CodeOptions