#[non_exhaustive]pub enum HighlightError {
GrammarLoad {
language: Language,
message: String,
},
Query {
language: Language,
row: usize,
column: usize,
offset: usize,
kind: HighlightQueryErrorKind,
message: String,
},
Parse {
language: Language,
},
InvalidEdit {
start_byte: usize,
old_end_byte: usize,
new_end_byte: usize,
old_len: usize,
new_len: usize,
},
}Expand description
A typed error produced while preparing runtime syntax highlighting.
These errors are recoverable for renderers: callers can surface the error and render the original source as plaintext.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
GrammarLoad
The tree-sitter parser rejected the selected grammar.
Fields
Query
The tree-sitter highlights query failed to compile.
Fields

kind: HighlightQueryErrorKindThe query error kind.
Parse
Tree-sitter failed to parse the source.
InvalidEdit
Buffer::edit received offsets that are out of bounds or not on
UTF-8 character boundaries.
The buffer’s state is unchanged when this error is returned.
Fields